# desktop_file_generator

Automate the creation of .desktop files for the Linux desktop

I find it odd that it's so hard to make a launcher for the desktop or dock (see [here](https://linuxconfig.org/how-to-create-desktop-shortcut-launcher-on-ubuntu-22-04-jammy-jellyfish-linux), for example).
This is just a short, interactive convenience script to make it a little easier.
